@@ -304,9 +304,9 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 
         if ms_drivers.match(driver) and os.name == 'nt':
             cstr_parts['MARS_Connection'] = 'yes'
-
+        print('cstr_parts--> ', cstr_parts)
         connstr = encode_connection_string(cstr_parts)
-
+        print('connection String--> ', connstr)
         # extra_params are glued on the end of the string without encoding,
         # so it's up to the settings writer to make sure they're appropriate -
         # use encode_connection_string if constructing from external input.
